@@ -1,5 +1,5 @@
 #!/bin/sh
-##                            Time-stamp: <2005-07-20 22:56:03 cyamauch>
+##                            Time-stamp: <2008-07-06 14:41:59 kojima>
 
 # 2004-08-07 added support of "AlwaysCore" mouse setting for laptop.
 # 2004-08-04 added support for Plamo-4.01.
@@ -171,14 +171,14 @@ CDPLAMO_CHK="`ls /usr/lib/setup/ | grep cdplamo`"
 
 TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
 
-LINE_BEGIN=`/usr/X11R6/bin/scanpci -v|nl -b a|grep '	  CLASS     0x03 0x'|awk 'NR==1{print $1}'`
+LINE_BEGIN=`/usr/X11R7/bin/scanpci -v|nl -b a|grep '	  CLASS     0x03 0x'|awk 'NR==1{print $1}'`
 if [ "$LINE_BEGIN" = "" ] ; then
   echo -n "" > $TMPFILE
 else
   LINE_BEGIN=`expr $LINE_BEGIN - 4`
   LINE_END=`expr $LINE_BEGIN + 10`
   #echo $LINE_BEGIN
-  /usr/X11R6/bin/scanpci -v | awk ${LINE_BEGIN}'<=NR&&NR<='${LINE_END}'{print}' > $TMPFILE
+  /usr/X11R7/bin/scanpci -v | awk ${LINE_BEGIN}'<=NR&&NR<='${LINE_END}'{print}' > $TMPFILE
   #echo $SCANRESULT
   if [ "`cat $TMPFILE | awk 'NR==1{print}'`" = "" ] ; then
     set_vendor_and_device `cat $TMPFILE | awk 'NR==2{print $9" "$11}'`
@@ -241,15 +241,15 @@ for i in $ARGS ; do
 done
 
 if [ "$XSERVER" = "xorg" ]; then
-  X11DIR=/usr/X11R6
+  X11DIR=/usr/X11R7
   CONFIGOPT="-config"
-  ( cd /usr/X11R6/bin ; rm -f X )
-  ( cd /usr/X11R6/bin ; ln -s Xorg X )
+  ( cd /usr/X11R7/bin ; rm -f X )
+  ( cd /usr/X11R7/bin ; ln -s Xorg X )
 else
   X11DIR=/usr/XFree86
   CONFIGOPT="-xf86config"
-  ( cd /usr/X11R6/bin ; rm -f X )
-  ( cd /usr/X11R6/bin ; ln -s ../../XFree86/bin/XFree86 X )
+  ( cd /usr/X11R7/bin ; rm -f X )
+  ( cd /usr/X11R7/bin ; ln -s ../../XFree86/bin/XFree86 X )
 fi
 PATH=$X11DIR:$PATH
 
@@ -340,15 +340,28 @@ fi
 #echo $WIDEMODE $MODENUM
 #exit
 
-TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
+# TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
+TMPDRIVER=`mktemp /tmp/tmp_tmpdriver_$$.XXXXXX`
 
-if [ "$VENDOR" != "" ] ; then
-  if [ "$CARD_VENDOR" != "" ] ; then
-    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION 1> $TMPFILE 2>/dev/null
-  else
-    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION -s $CARD_VENDOR -b $CARD 1> $TMPFILE 2>/dev/null
-  fi
+# if [ "$VENDOR" != "" ] ; then
+#  if [ "$CARD_VENDOR" != "" ] ; then
+#    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION 1> $TMPFILE 2>/dev/null
+#  else
+#    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION -s $CARD_VENDOR -b $CARD 1> $TMPFILE 2>/dev/null
+#  fi
+#fi
+
+moved_flag=0
+if [ -f /etc/X11/xorg.conf ]; then
+    mv /etc/X11/xorg.conf /etc/X11/xorg.conf.orig
+    moved_flag=1
 fi
+newdriver=`/usr/X11R7/bin/Xorg -probeonly 2>&1 | grep 'New driver' | cut -d' ' -f4 | sed -e 's/"//g'`
+echo $newdriver > $TMPDRIVER
+if [ $moved_flag = "1" ]; then
+    mv /etc/X11/xorg.conf.orig /etc/X11/xorg.conf
+fi
+
 
 # 855GM ʥޥ VBIOS ٤֤ʤåץȥåץޥѤк
 # See http://wiki.0-24.jp/?Linux%2FY2%A4%C7SXGA%2B
@@ -364,12 +377,12 @@ if [ "$CDPLAMO_CHK" != "" -a "$LCD_CHK" != "" -a "$NO855TEST" = "" ]; then
     fi
     if [ "$LFP_RESOLUTION" != "" ]; then
       TMP855FILE=`mktemp /tmp/tmp855_xfplamoconfig_$$.XXXXXX`
-      /usr/X11R6/bin/855resolution -l | grep 'Mode ' > $TMP855FILE
+      /usr/bin/855resolution -l | grep 'Mode ' > $TMP855FILE
       MODE_CHK="`cat $TMP855FILE | grep \" ${LFP_RESOLUTION},\"`"
       if [ "$MODE_CHK" = "" ]; then
         MODE_LIST="`cat $TMP855FILE | grep ' 800x600,' | awk '{print $2}'`"
         for i in $MODE_LIST ; do
-          /usr/X11R6/bin/855resolution $i `echo $LFP_RESOLUTION | tr 'x' ' '` 1> /dev/null
+          /usr/bin/855resolution $i `echo $LFP_RESOLUTION | tr 'x' ' '` 1> /dev/null
         done
       fi
       rm -f $TMP855FILE
@@ -393,33 +406,33 @@ EndSection
 Section "Files"
         #RgbPath      "$X11DIR/lib/X11/rgb"
         #ModulePath   "$X11DIR/lib/modules"
-        FontPath     "/usr/X11R6/lib/X11/fonts/local/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/75dpi/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/100dpi/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/TrueType/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/ghostscript/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Type1/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Bitmap/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/misc/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Speedo/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/freefont/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/CID/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/75dpi/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/100dpi/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Bitmap/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/misc/"
+	FontPath     "unix/:7100"
+        # FontPath     "/usr/X11R7/lib/X11/fonts/local/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/misc/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/75dpi/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/100dpi/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Bitmap/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/TTF/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/TrueType/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Type1/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Speedo/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/freefont/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/ghostscript/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/misc/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/75dpi/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/100dpi/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Bitmap/"
+        # FontPath     "/usr/X11R7/lib/X11/fonts/CID/"
 EndSection
 
 Section "Module"
         Load  "freetype"
         Load  "type1"
-        Load  "speedo"
         Load  "extmod"
         Load  "glx"
-        Load  "dri"
         Load  "dbe"
-        #Load  "record"
-        #Load  "xtrap"
+        Load  "record"
+        Load  "xtrap"
 EndSection
 
 EOF
@@ -560,7 +573,8 @@ echo '        Identifier  "Card0"'
 if [ "$XMODULE" = "" ] ; then
   echo -n '        Driver      '
   echo -n '"'
-  GETCONF_MODULE="`cat $TMPFILE | awk 'NR==1{print $1}'`"
+  #GETCONF_MODULE="`cat $TMPFILE | awk 'NR==1{print $1}'`"
+  GETCONF_MODULE="`cat $TMPDRIVER`"
   if [ "$GETCONF_MODULE" = "" ] ; then
     echo -n "$FALLBACK_XMODULE"
   else
@@ -588,8 +602,8 @@ if [ "$LCD_CHK" != "" -a "$XSCREEN" = "" ]; then
   echo '        Identifier "Screen0"'
   echo '        Device     "Card0"'
   echo '        Monitor    "Monitor0"'
-  echo '        Option     "NoDoublescan" "True"'
-  echo '        Option     "NoInterlace" "True"'
+#  echo '        Option     "NoDoublescan" "True"'
+#  echo '        Option     "NoInterlace" "True"'
   echo 'EndSection'
   echo ''
 else
@@ -640,5 +654,5 @@ EndSection
 
 EOF
 
-rm -f $TMPFILE
+ rm -f $TMPFILE $TMPDRIVER
 
